@@ -12,7 +12,7 @@ my $loglevel=3;
 my $logging =0;
 my $logfile = "/tmp/".getpwuid($>)."-audit.log";
 
-$VERSION = '1.9';
+$VERSION = '2.0';
 
 sub import {
     my $pkg = shift;
@@ -94,12 +94,24 @@ sub accept {
 		flock(FH, LOCK_EX) 
             or _log(1,"Couldn't get exclusive lock on $file");
         seek FH, 0, 2;
-		if ((${$self->{obj}->body}[0] !~ /^From\s/) && (exists $ENV{UFLINE})) {
-		    _log(3,"Looks qmail, but preline not run, prepending UFLINE, RPLINE, DTLINE");
+                if (${$self->{obj}->body}[0] !~ /^From\s/) {
+                    if (exists $ENV{UFLINE}) {
+                        _log(3,"Looks qmail, but preline not run, prepending UFLINE, RPLINE, DTLINE");
 			print FH $ENV{UFLINE};
 			print FH $ENV{RPLINE};
 			print FH $ENV{DTLINE};
-		}
+                    } else {
+                        _log(3,"No mbox From line, making one up.");
+                        my $from = $self->{obj}->head()->get('Return-path') ||
+                            $self->{obj}->head()->get('Sender') ||
+                            $self->{obj}->head()->get('Reply-To') ||
+                            $self->{obj}->head()->get('From') ||
+                            '';
+                        chomp $from;
+                        ($from) = $from =~ /<([^>]+)/ if ($from =~ /<.*>/);
+                        print FH "From $from ", scalar(localtime), "\n";
+                    }
+                }
 		print FH $self->{obj}->as_mbox_string;
 		flock(FH, LOCK_UN)
             or _log(1,"Couldn't unlock on $file");
@@ -142,6 +154,8 @@ sub pipe {
 
 sub header { $_[0]->{obj}->head->as_string() }
 sub put_header { $_[0]->{obj}->head->add($_[1],$_[2]); }
+sub replace_header { $_[0]->{obj}->head->replace ($_[1],$_[2]); }
+sub delete_header { $_[0]->{obj}->head->delete ($_[1]); }
 sub tidy { $_[0]->{obj}->tidy_body() }
 sub from { $_[0]->{obj}->head->get("From") }
 sub to { $_[0]->{obj}->head->get("To") }
@@ -170,7 +184,7 @@ Mail::Audit - Library for creating easy mail filters
 	use Mail::Audit; # use Mail::Audit qw(...plugins...);
 	my $mail = Mail::Audit->new;
 	$mail->pipe("listgate p5p") if ($mail->from =~ /perl5-porters/);
-	$mail->accept("perl) if ($mail->from =~ /perl/);
+	$mail->accept("perl") if ($mail->from =~ /perl/);
 	$mail->reject("We do not accept spam") if looks_like_spam($mail);
 	$mail->ignore if $mail->subject =~ /boring/i;
 	...
@@ -248,10 +262,18 @@ Tidies up the email as per L<Mail::Internet>
 
 Retrieves the named header from the mail message.
 
-=item C<put($header, $value>)
+=item C<put_header($header, $value)>
 
 Inserts a new header into the mail message with the given value.
 
+=item C<replace_header($header, $value)>
+
+Removes the old header, adds a new one.
+
+=item C<delete_header($header)>
+
+Guess.
+
 =item C<body>
 
 Returns a reference to an array of lines in the body of the email.
@@ -294,6 +316,11 @@ bcc
 
 =back
 
+=head1 LICENSE
+
+The usual. This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
 =head1 BUGS
 
 Fewer than before.
@@ -304,4 +331,5 @@ Simon Cozens <simon@cpan.org>
 
 =head1 SEE ALSO
 
-L<Mail::Internet>, L<Mail::SMTP>
+L<Mail::Internet>, L<Mail::SMTP>, L<Mail::Audit::List>, L<Mail::Audit::PGP>,
+L<Mail::Audit::MAPS>, L<Mail::Audit::KillDups>, L<Mail::Audit::Razor>...
